# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

Name:           dom4j
Version:        2.0.0
Release:        %mkrel 6
Group:          Development/Java
Epoch:          0
Summary:        Open Source XML framework for Java
License:        BSD
URL:            https://dom4j.github.io/
BuildArch:      noarch

Source0:        https://github.com/%{name}/%{name}/archive/v%{version}.tar.gz
Source1:        https://repo1.maven.org/maven2/org/%{name}/%{name}/%{version}/%{name}-%{version}.pom

Patch0:         dom4j-2.0.0-CVE-2018-1000632.patch
Patch1:         dom4j-2.0.0-fix-tests-with-invalid-QNames.patch
Patch2:		dom4j-2.0.0-CVE-2020-10683.patch
Patch3:		00-fix-java11-compilation.patch

Obsoletes:      %{name}-demo < 2.0.0
Obsoletes:      %{name}-manual < 2.0.0

BuildRequires:  maven-local
BuildRequires:  mvn(jaxen:jaxen)
BuildRequires:  mvn(net.java.dev.msv:xsdlib)
BuildRequires:  mvn(xpp3:xpp3)
BuildRequires:  mvn(javax.xml.bind:jaxb-api)

# Test deps
BuildRequires:  mvn(org.testng:testng)
BuildRequires:  mvn(xerces:xercesImpl)
BuildRequires:  mvn(xalan:xalan)

%description
dom4j is an Open Source XML framework for Java. dom4j allows you to read,
write, navigate, create and modify XML documents. dom4j integrates with
DOM and SAX and is seamlessly integrated with full XPath support.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
Javadoc for %{name}.


%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%mvn_alias org.%{name}:%{name} %{name}:%{name}
%mvn_file : %{name}/%{name} %{name}

cp %{SOURCE1} pom.xml

# optional deps missing from pom
%pom_add_dep net.java.dev.msv:xsdlib::provided
%pom_add_dep xpp3:xpp3::provided
%pom_add_dep javax.xml.bind:jaxb-api::provided

# Remove support for ancient xpp2 (deprecated and not developed since 2003)
rm -r src/main/java/org/dom4j/xpp
rm src/main/java/org/dom4j/io/XPPReader.java

# non-deterministic test
rm src/test/java/org/dom4j/util/PerThreadSingletonTest.java

%build
%mvn_build -- -Dproject.build.sourceEncoding=UTF-8 -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -f .mfiles
%license LICENSE
%doc README.md

%files javadoc -f .mfiles-javadoc
%license LICENSE




%changelog
* Mon Dec 28 2020 luigiwalser <luigiwalser> 0:2.0.0-6.mga8
+ Revision: 1664546
- add patch from fedora to fix build with Java 11
- Remove dependency on bea-stax-api
- rediff patch from debian to fix CVE-2020-10683

* Fri Feb 14 2020 umeabot <umeabot> 0:2.0.0-5.mga8
+ Revision: 1522617
- Mageia 8 Mass Rebuild

* Sun Feb 03 2019 daviddavid <daviddavid> 0:2.0.0-4.mga7
+ Revision: 1362802
- add upstream patch fix tests with invalid QNames
+ luigiwalser <luigiwalser>
- add upstream patch to fix CVE-2018-1000632

* Thu Sep 20 2018 umeabot <umeabot> 0:2.0.0-3.mga7
+ Revision: 1278043
- Mageia 7 Mass Rebuild

* Wed Oct 04 2017 daviddavid <daviddavid> 0:2.0.0-2.mga7
+ Revision: 1168278
- Explicitly specify source encoding

* Wed Oct 04 2017 daviddavid <daviddavid> 0:2.0.0-1.mga7
+ Revision: 1168267
- fix javadoc build (error: unmappable character for encoding ANSI_X3.4-1968)
- Upgrade to upstream version 2.0.0 (sync with fc27)

* Thu May 11 2017 neoclust <neoclust> 0:1.6.1-28.mga6
+ Revision: 1100217
- Fix build-dependency on jaxen

* Wed Mar 02 2016 neoclust <neoclust> 0:1.6.1-27.mga6
+ Revision: 982307
- Second rebuild of the java stack

* Sun Feb 21 2016 neoclust <neoclust> 0:1.6.1-26.mga6
+ Revision: 975760
- First rebuild of the java stack
- sync package dom4j with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Jan 11 2015 pterjan <pterjan> 0:1.6.1-23.mga5
+ Revision: 809839
- Sync with Fedora 21

* Wed Oct 15 2014 umeabot <umeabot> 0:1.6.1-22.mga5
+ Revision: 738938
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0:1.6.1-21.mga5
+ Revision: 678810
- Mageia 5 Mass Rebuild

* Sun May 11 2014 dmorgan <dmorgan> 0:1.6.1-20.mga5
+ Revision: 621975
- Port to JAXP 1.4

* Fri Oct 18 2013 umeabot <umeabot> 0:1.6.1-6.mga4
+ Revision: 503939
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 0:1.6.1-5.mga3
+ Revision: 349058
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 dmorgan <dmorgan> 0:1.6.1-4.mga3
+ Revision: 325102
- Add maven pom
- Remove gcj support

* Mon Jan 17 2011 dmorgan <dmorgan> 0:1.6.1-2.2.5.mga1
+ Revision: 21201
- imported package dom4j


* Sat Mar 07 2009 Antoine Ginies <aginies@mandriva.com> 0:1.6.1-2.2.5mdv2009.1
+ Revision: 350834
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 0:1.6.1-2.2.4mdv2008.1
+ Revision: 136373
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

  + Anssi Hannula <anssi@mandriva.org>
    - buildrequire java-rpmbuild, i.e. build with icedtea on x86(_64)

* Sat Sep 15 2007 Anssi Hannula <anssi@mandriva.org> 0:1.6.1-2.2.3mdv2008.0
+ Revision: 87332
- rebuild to filter out autorequires of GCJ AOT objects
- remove unnecessary Requires(post) on java-gcj-compat

* Fri Jul 06 2007 David Walluck <walluck@mandriva.org> 0:1.6.1-2.2.2mdv2008.0
+ Revision: 48920
- workaround dom4j bug #1618750

* Wed Jul 04 2007 David Walluck <walluck@mandriva.org> 0:1.6.1-2.2.1mdv2008.0
+ Revision: 47796
- Import dom4j



* Mon Mar 26 2007 Nuno Santos <nsantos@redhat.com> - 0:1.6.1-2jpp.2
- fix unowned directory

* Wed Feb 14 2007 Jeff Johnston <jjohnstn@redhat.com> - 0:1.6.1-2jpp.1
- Resolves: #227049
- Updated per Fedora package review process
- Modified dom4j-1.6.1-build_xml.patch to include jaxp 1.2 apis on
  boot classpath
- Added new patch for javadocs
- Add buildrequires for jaxp = 1.2

* Mon Jan 30 2006 Ralph Apel <r.apel@r-apel.de> - 0:1.6.1-2jpp
- Change STAX dependency to free bea-stax and bea-stax-api

* Wed Aug 17 2005 Ralph Apel <r.apel@r-apel.de> - 0:1.6.1-1jpp
- Upgrade to 1.6.1
- Now requires xpp3 additionally to xpp2

* Thu Sep 09 2004 Ralph Apel <r.apel@r-apel.de> - 0:1.5-1jpp
- Upgrade to 1.5
- Drop saxpath requirement as this is now included in jaxen

* Fri Aug 20 2004 Ralph Apel <r.apel@r-apel.de> - 0:1.4-3jpp
- Upgrade to Ant 1.6.X
- Build with ant-1.6.2

* Tue Jul 06 2004 Ralph Apel <r.apel@r-apel.de> - 0:1.4-2jpp
- Replace non-free msv with free relaxngDatatype xsdlib isorelax msv-strict
- Relax some versioned dependencies

* Mon Jan 19 2004 Ralph Apel <r.apel@r-apel.de> - 0:1.4-1jpp
- First JPackage release
